@@ -14,17 +14,16 @@ doubleGauss.refit <- function(part1.list, subj = NULL, group = NULL, curves = NU
 	if(!is.null(info.matrix)) {
 		if(any(is.na(info.matrix))) stop("Can't have any NA or NaN values in info.matrix")
 		if(!is.matrix(info.matrix)) stop("info.matrix should be a matrix")
-		if(!is.numeric(info.matrix)) stop("info.matrix should be numeric")
 		if(ncol(info.matrix) != 9)
 			stop("info.matrix should have 7 columns:
 			subject, group, curves, mu, height, sigma1, sigma2, base1, base2
 			If diffs=FALSE, curves column is not used, so just set to any number")
-		subj <- info.matrix[,1]
+		subj <- as.numeric(info.matrix[,1])
 		group <- info.matrix[,2]
-		curves <- info.matrix[,3]
+		curves <- as.numeric(info.matrix[,3])
 		params <- list()
 		for(i in 1:nrow(info.matrix)) {
-			params[[i]] <- info.matrix[i, 4:9]
+			params[[i]] <- as.numeric(info.matrix[i, 4:9])
 		}
 	}
 	
@@ -38,7 +37,15 @@ doubleGauss.refit <- function(part1.list, subj = NULL, group = NULL, curves = NU
 	if(!is.null(cor) && length(cor) != length(subj))
 		stop("Length of 'cor' should be equal to length of 'subj' and 'group'")
 	if(is.null(cor)) cor <- rep(part1.list$cor, length(subj))
-		
+  
+  if(any(!(group %in% part1.list$groups))) stop("Some values in 'group' input are not valid groups from the data set")
+  group <- ifelse(group == part1.list$groups[1], 1, 2)
+  
+  if(!all((group == 1 & subj %in% part1.list$id.nums.g1) | (group == 2 & subj %in% part1.list$id.nums.g2))) stop("Some subject numbers aren't in corresponding group")
+  if(any(group == 1)) subj[group == 1] <- vapply(subj[group == 1], function(x) which(part1.list$id.nums.g1 == x), numeric(1))
+	if(any(group == 2)) subj[group == 2] <- vapply(subj[group == 2], function(x) which(part1.list$id.nums.g2 == x), numeric(1))
+	subj <- as.numeric(subj)
+	
 	diffs <- part1.list$diffs
 	if(diffs && length(curves) != length(subj)) stop("Length of 'curves' and 'subj' need to be the same")
 	
@@ -128,9 +135,14 @@ doubleGauss.refit <- function(part1.list, subj = NULL, group = NULL, curves = NU
 					SSE <- sum(y.err ^ 2)
 					R2.g1.2[subj[i]] <- 1 - SSE / SSY
 				}
-				cat("Subject = ", subj[i], ", Group = ", group[i], ", Curve = ", curves[i],
-											", Old R2 = ", round(old.R2, 3), ", New R2 = ", round(R2.g1.2[subj[i]], 3),
-											"\n\t Old AR1 = ", as.logical(old.cor), ", New AR1 = ", as.logical(cor.3[subj[i]]), "\n")
+				cat("Subject = ", as.character(id.nums.g1[subj[i]]),
+						", Group = ", as.character(groups[group[i]]),
+						", Curve = ", curves[i],
+						", Old R2 = ", round(old.R2, 3),
+						", New R2 = ", round(R2.g1.2[subj[i]], 3),
+						"\n\t Old AR1 = ", as.logical(old.cor),
+						", New AR1 = ", as.logical(cor.3[subj[i]]),
+						"\n")
 			} else {
 				old.R2 <- R2.g1.1[subj[i]]
 				old.cor <- cor.1[subj[i]]
@@ -155,9 +167,14 @@ doubleGauss.refit <- function(part1.list, subj = NULL, group = NULL, curves = NU
 					SSE <- sum(y.err ^ 2)
 					R2.g1.1[subj[i]] <- 1 - SSE / SSY
 				}
-				cat("Subject = ", subj[i], ", Group = ", group[i], ", Curve = ", curves[i],
-										", Old R2 = ", round(old.R2, 3), ", New R2 = ", round(R2.g1.1[subj[i]], 3),
-										"\n\t Old AR1 = ", as.logical(old.cor), ", New AR1 = ", as.logical(cor.1[subj[i]]), "\n")
+				cat("Subject = ", as.character(id.nums.g1[subj[i]]),
+						", Group = ", as.character(groups[group[i]]),
+						", Curve = ", curves[i],
+						", Old R2 = ", round(old.R2, 3),
+						", New R2 = ", round(R2.g1.1[subj[i]], 3),
+						"\n\t Old AR1 = ", as.logical(old.cor),
+						", New AR1 = ", as.logical(cor.1[subj[i]]),
+						"\n")
 			}
 		} else {
 			if(diffs) {
@@ -194,9 +211,14 @@ doubleGauss.refit <- function(part1.list, subj = NULL, group = NULL, curves = NU
 					SSE <- sum(y.err ^ 2)
 					R2.g2.2[subj[i]] <- 1 - SSE / SSY
 				}
-				cat("Subject = ", subj[i], ", Group = ", group[i], ", Curve = ", curves[i],
-										", Old R2 = ", round(old.R2, 3), ", New R2 = ", round(R2.g2.2[subj[i]], 3),
-										"\n\t  Old AR1 = ", as.logical(old.cor), ", New AR1 = ", as.logical(cor.4[subj[i]]), "\n")
+				cat("Subject = ", as.character(id.nums.g2[subj[i]]),
+						", Group = ", as.character(groups[group[i]]),
+						", Curve = ", curves[i],
+						", Old R2 = ", round(old.R2, 3),
+						", New R2 = ", round(R2.g2.2[subj[i]], 3),
+						"\n\t Old AR1 = ", as.logical(old.cor),
+						", New AR1 = ", as.logical(cor.4[subj[i]]),
+						"\n")
 			} else {
 				old.R2 <- R2.g2.1[subj[i]]
 				old.cor <- cor.2[subj[i]]
@@ -221,9 +243,14 @@ doubleGauss.refit <- function(part1.list, subj = NULL, group = NULL, curves = NU
 					SSE <- sum(y.err ^ 2)
 					R2.g2.1[subj[i]] <- 1 - SSE / SSY
 				}
-				cat("Subject = ", subj[i], ", Group = ", group[i], ", Curve = ", curves[i],
-										", Old R2 = ", round(old.R2, 3), ", New R2 = ", round(R2.g2.1[subj[i]], 3),
-										"\n\t  Old AR1 = ", as.logical(old.cor), ", New AR1 = ", as.logical(cor.2[subj[i]]), "\n")
+				cat("Subject = ", as.character(id.nums.g2[subj[i]]),
+						", Group = ", as.character(groups[group[i]]),
+						", Curve = ", curves[i],
+						", Old R2 = ", round(old.R2, 3),
+						", New R2 = ", round(R2.g2.1[subj[i]], 3),
+						"\n\t Old AR1 = ", as.logical(old.cor),
+						", New AR1 = ", as.logical(cor.2[subj[i]]),
+						"\n")
 			}
 		}
 	}
